@@ -20,7 +20,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(8.5.3);
+  our $VERSION = qv(8.5.4);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -244,7 +244,7 @@ sub filter {
     }gmse;
 
     if ($DEBUG eq "verify") {
-      $prefix .= " ($_,\@_dummy)" if $entry;
+      $prefix .= " ($_,\@_dummy)";
       $suffix = "" unless $entry;
     }
 
